@@ -22,14 +22,14 @@ import (
 
 	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	"github.com/stretchr/testify/require"
-	"k8s.io/api/core/v1"
+	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 var (
 	defaultTestConfig = Config{
-		ConfigReloaderImage:          "quay.io/coreos/configmap-reload:latest",
+		ConfigReloaderImage:          "jimmidyson/configmap-reload:latest",
 		ConfigReloaderCPU:            "100m",
 		ConfigReloaderMemory:         "25Mi",
 		AlertmanagerDefaultBaseImage: "quay.io/prometheus/alertmanager",
@@ -478,7 +478,7 @@ func sliceContains(slice []string, match string) bool {
 
 func TestSidecarsNoCPULimits(t *testing.T) {
 	testConfig := Config{
-		ConfigReloaderImage:          "quay.io/coreos/configmap-reload:latest",
+		ConfigReloaderImage:          "jimmidyson/configmap-reload:latest",
 		ConfigReloaderCPU:            "0",
 		ConfigReloaderMemory:         "25Mi",
 		AlertmanagerDefaultBaseImage: "quay.io/prometheus/alertmanager",
@@ -504,7 +504,7 @@ func TestSidecarsNoCPULimits(t *testing.T) {
 
 func TestSidecarsNoMemoryLimits(t *testing.T) {
 	testConfig := Config{
-		ConfigReloaderImage:          "quay.io/coreos/configmap-reload:latest",
+		ConfigReloaderImage:          "jimmidyson/configmap-reload:latest",
 		ConfigReloaderCPU:            "100m",
 		ConfigReloaderMemory:         "0",
 		AlertmanagerDefaultBaseImage: "quay.io/prometheus/alertmanager",
@@ -527,3 +527,18 @@ func TestSidecarsNoMemoryLimits(t *testing.T) {
 		}
 	}
 }
+
+func TestTerminationPolicy(t *testing.T) {
+	sset, err := makeStatefulSet(&monitoringv1.Alertmanager{
+		Spec: monitoringv1.AlertmanagerSpec{},
+	}, nil, defaultTestConfig)
+	if err != nil {
+		t.Fatalf("Unexpected error while making StatefulSet: %v", err)
+	}
+
+	for _, c := range sset.Spec.Template.Spec.Containers {
+		if c.TerminationMessagePolicy != v1.TerminationMessageFallbackToLogsOnError {
+			t.Fatalf("Unexpected TermintationMessagePolicy. Expected %v got %v", v1.TerminationMessageFallbackToLogsOnError, c.TerminationMessagePolicy)
+		}
+	}
+}
